@@ -5,7 +5,9 @@
 #include <string.h>
 #include <errno.h>
 #include <sys/time.h>
-#include <pthread.h>
+#ifndef S_SPLINT_S
+#include <pthread.h>	/* pacifies OpenBSD's compiler */
+#endif
 #include <math.h>
 
 #include "gpsd.h"
@@ -64,8 +66,8 @@ extern char *strtok_r(char *, const char *, char **);
 /* 
  * check the environment to determine proper GPS units
  *
- * clients should only call this if no user preference on the command line or
- * Xresources
+ * clients should only call this if no user preference is specified on 
+ * the command line or via X resources.
  *
  * return imperial    - Use miles/feet
  *        nautical    - Use knots/feet
@@ -296,6 +298,7 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata)
 		case 'O':
 		    if (sp[2] == '?') {
 			gpsdata->set = MODE_SET | STATUS_SET;
+			gpsdata->status = STATUS_NO_FIX;
 			gps_clear_fix(&gpsdata->fix);
 		    } else {
 			struct gps_fix_t nf;
@@ -338,7 +341,9 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata)
 			    nf.pitch = nf.roll = nf.dip = NAN;
 			    gpsdata->fix = nf;
 			    (void)strcpy(gpsdata->tag, tag);
-			    gpsdata->set = TIME_SET|TIMERR_SET|LATLON_SET|MODE_SET;
+			    gpsdata->set |= TIME_SET|TIMERR_SET|LATLON_SET|MODE_SET;
+			    gpsdata->status = STATUS_FIX;
+			    gpsdata->set |= STATUS_SET;
 			}
 		    }
 		    break;
@@ -451,7 +456,7 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata)
 		    break;
 		case '$':
 		    /*@ +matchanyintegral @*/
-		    (void)sscanf(sp, "$=%s %u %lf %lf %lf %lf %lf %lf", 
+		    (void)sscanf(sp, "$=%s %ld %lf %lf %lf %lf %lf %lf", 
 			   gpsdata->tag,
 			   &gpsdata->sentence_length,
 			   &gpsdata->fix.time, 
